@@ -238,31 +238,18 @@ sub epath {
      my $self = shift;
      my $old = $self->_elem('path', @_);
      return '/' if !defined($old) || !length($old);
-     return '/$old' if $old !~ m|^/| && defined $self->{'netloc'};
+     return "/$old" if $old !~ m|^/| && defined $self->{'netloc'};
      $old;
 }
 
 sub path {
     my $self = shift;
     my $old = $self->_elem('path',
-			   map { uri_escape($_,
-					    $URI::URL::reserved_no_slash)
-			       } @_);
-
-    if ($URI::URL::COMPAT_VER_3) {
-	# We used to get rid of the leading "/" in the path
-	if (defined $old) {
-	    $old =~ s|^/||;
-	    Carp::croak("Path components contain '/' (you must call epath)")
-		if $old =~ /%2[fF]/;
-	    return uri_unescape($old);
-	}
-	return undef;
-    }
-
+		      map uri_escape($_, $URI::URL::reserved_no_slash), @_);
+    return unless defined wantarray;
     return '/' if !defined($old) || !length($old);
     Carp::croak("Path components contain '/' (you must call epath)")
-	if $old =~ /%2[fF]/;
+	if $old =~ /%2[fF]/ and !@_;
     $old = "/$old" if $old !~ m|^/| && defined $self->{'netloc'};
     return uri_unescape($old);
 }
@@ -295,7 +282,7 @@ sub equery   { shift->_elem('query',   @_); }
 sub query {
     my $self = shift;
     my $old = $self->_elem('query', map { uri_escape($_, $URI::URL::reserved_no_form) } @_);
-    if (defined $old) {
+    if (defined(wantarray) && defined($old)) {
 	if ($old =~ /%(?:26|2[bB]|3[dD])/) {  # contains escaped '=' '&' or '+'
 	    my $mess;
 	    for ($old) {
@@ -438,7 +425,7 @@ sub abs
 
 # The oposite of $url->abs.  Return a URL as much relative as possible
 sub rel {
-    my($self, $base) = shift;
+    my($self, $base) = @_;
     my $rel = $self->clone;
     $base = $self->base unless $base;
     return $rel unless $base;
@@ -450,34 +437,44 @@ sub rel {
 	# it is already relative
 	return $rel;
     }
+    $path = "/" if $path eq '';
     
     my($bscheme, $bnetloc, $bpath) = @{$base}{qw(scheme netloc path)};
-    $bpath = "/" unless length $bpath;  # a slash is default
-    for ($netloc, $bnetloc) { $_ = '' unless defined }  # these can be empty
+    for ($bscheme, $bnetloc, $netloc) { $_ = '' unless defined }
+
     unless ($scheme eq $bscheme && $netloc eq $bnetloc) {
 	# different location, can't make it relative
 	return $rel;
     }
+    $bpath = "/" if $bpath eq '';
 
     # Make it relative by eliminating scheme and netloc
     $rel->{'scheme'} = undef;
     $rel->netloc(undef);
 
     # This loop is based on code from Nicolai Langfeldt <janl@ifi.uio.no>.
-    # It will remove all common initial path components.
+    # First we calculate common initial path components length ($li).
+    my $li = 1;
     while (1) {
-	#print "PATHS: $path $bpath\n";
-	my $i = index($path, '/');
-	last unless $i >=0 && $i == index($bpath, '/') &&
-                    substr($path,0,$i) eq substr($bpath,0,$i);
-	substr($path, 0, $i+1)  = '';
-	substr($bpath, 0, $i+1) = '';
+	my $i = index($path, '/', $li);
+	last if $i < 0 ||
+                $i != index($bpath, '/', $li) ||
+	        substr($path,$li,$i-$li) ne substr($bpath,$li,$i-$li);
+	$li=$i+1;
+    }
+    # then we nuke it from both paths
+    substr($path, 0,$li) = '';
+    substr($bpath,0,$li) = '';
+
+    if ($path eq $bpath && defined($rel->frag) && !defined($rel->equery)) {
+        $rel->epath('');
+    } else {
+        # Add one "../" for each path component left in the base path
+        $path = ('../' x $bpath =~ tr|/|/|) . $path;
+	$path = "./" if $path eq "";
+        $rel->epath($path);
     }
 
-    # Add one "../" for each path component left in the base path
-    $path = ('../' x $bpath =~ tr|/|/|) . $path;
-
-    $rel->epath($path);
     $rel;
 }
 
